@@ -15,31 +15,18 @@
 #include "ui_configsecurity.h"
 
 #include <KConfigDialog>
-#include <KIcon>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KMessageBox>
-#include <KStandardGuiItem>
-#include <KSystemTimeZone>
-#include <KToolInvocation>
 #include <KStandardAction>
 #include <KActionCollection>
 #include <KLineEdit>
 #include <KNewPasswordDialog>
 
-#include <QtGui/QWidget>
-#include <QtGui/QSizePolicy>
+#include <QIcon>
+#include <QWidget>
+#include <QSizePolicy>
 #include <QtNetwork/QNetworkInterface>
 
-#ifdef KRFB_WITH_KDE_TELEPATHY
-#include "tubesrfbserver.h"
-#include <TelepathyQt/PendingReady>
-#include <TelepathyQt/PendingChannelRequest>
-#include <KTp/actions.h>
-#include <KTp/Widgets/contact-view-widget.h>
-#include <KTp/Models/contacts-list-model.h>
-#include <KTp/Models/contacts-filter-model.h>
-#endif
-
 class TCP: public QWidget, public Ui::TCP
 {
 public:
@@ -69,26 +56,26 @@ MainWindow::MainWindow(QWidget *parent)
 
     QWidget *mainWidget = new QWidget;
     m_ui.setupUi(mainWidget);
-    m_ui.krfbIconLabel->setPixmap(KIcon("krfb").pixmap(128));
+    m_ui.krfbIconLabel->setPixmap(QIcon::fromTheme("krfb").pixmap(128));
     m_ui.enableUnattendedCheckBox->setChecked(
             InvitationsRfbServer::instance->allowUnattendedAccess());
 
     setCentralWidget(mainWidget);
 
-    connect(m_ui.passwordEditButton,SIGNAL(clicked()),
-            this,SLOT(editPassword()));
-    connect(m_ui.enableSharingCheckBox,SIGNAL(toggled(bool)),
-            this, SLOT(toggleDesktopSharing(bool)));
-    connect(m_ui.enableUnattendedCheckBox, SIGNAL(toggled(bool)),
-            InvitationsRfbServer::instance, SLOT(toggleUnattendedAccess(bool)));
-    connect(m_ui.unattendedPasswordButton, SIGNAL(clicked()),
-            this, SLOT(editUnattendedPassword()));
-    connect(m_ui.addressAboutButton, SIGNAL(clicked()),
-            this, SLOT(aboutConnectionAddress()));
-    connect(m_ui.unattendedAboutButton, SIGNAL(clicked()),
-            this, SLOT(aboutUnattendedMode()));
-    connect(InvitationsRfbServer::instance, SIGNAL(passwordChanged(const QString&)),
-            this, SLOT(passwordChanged(const QString&)));
+    connect(m_ui.passwordEditButton, &QToolButton::clicked,
+            this, &MainWindow::editPassword);
+    connect(m_ui.enableSharingCheckBox, &QCheckBox::toggled,
+            this, &MainWindow::toggleDesktopSharing);
+    connect(m_ui.enableUnattendedCheckBox, &QCheckBox::toggled,
+            InvitationsRfbServer::instance, &InvitationsRfbServer::toggleUnattendedAccess);
+    connect(m_ui.unattendedPasswordButton, &QPushButton::clicked,
+            this, &MainWindow::editUnattendedPassword);
+    connect(m_ui.addressAboutButton, &QToolButton::clicked,
+            this, &MainWindow::aboutConnectionAddress);
+    connect(m_ui.unattendedAboutButton, &QToolButton::clicked,
+            this, &MainWindow::aboutUnattendedMode);
+    connect(InvitationsRfbServer::instance, &InvitationsRfbServer::passwordChanged,
+            this, &MainWindow::passwordChanged);
 
     // Figure out the address
     int port = KrfbConfig::port();
@@ -108,36 +95,15 @@ MainWindow::MainWindow(QWidget *parent)
     m_ui.passwordDisplayLabel->setText(
             InvitationsRfbServer::instance->desktopPassword());
 
-
-#ifdef KRFB_WITH_KDE_TELEPATHY
-
-    m_contactViewWidget = new KTp::ContactViewWidget(
-            TubesRfbServer::instance->contactsListModel(), this);
-
-    m_contactViewWidget->setEnabled(false);
-    connect(m_ui.enableSharingCheckBox, SIGNAL(toggled(bool)),
-            m_contactViewWidget, SLOT(setEnabled(bool)));
-    m_contactViewWidget->setIconSize(QSize(32,32));
-    m_contactViewWidget->setMinimumWidth(120);
-    m_contactViewWidget->setMaximumWidth(360);
-    m_contactViewWidget->setMinimumHeight(300);
-    m_contactViewWidget->contactFilterLineEdit()->setClickMessage(i18n("Search in Contacts..."));
-    m_contactViewWidget->filter()->setPresenceTypeFilterFlags(KTp::ContactsFilterModel::ShowOnlyConnected);
-    m_contactViewWidget->filter()->setTubesFilterStrings(QStringList("rfb"));
-    m_contactViewWidget->filter()->setCapabilityFilterFlags(KTp::ContactsFilterModel::FilterByTubes);
-
-    m_contactViewWidget->setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding));
-    m_ui.tpContactsLayout->addWidget(m_contactViewWidget);
-    connect(m_contactViewWidget, SIGNAL(contactDoubleClicked(const Tp::AccountPtr &, const KTp::ContactPtr &)),
-        this, SLOT(onContactDoubleClicked(const Tp::AccountPtr &, const KTp::ContactPtr &)));
-#endif
-
-
     KStandardAction::quit(QCoreApplication::instance(), SLOT(quit()), actionCollection());
     KStandardAction::preferences(this, SLOT(showConfiguration()), actionCollection());
 
     setupGUI();
 
+    if (KrfbConfig::allowDesktopControl()) {
+      m_ui.enableSharingCheckBox->setChecked(true);
+    }
+
     setAutoSaveSettings();
 }
 
@@ -149,7 +115,7 @@ void MainWindow::editPassword()
 {
     if(m_passwordEditable) {
         m_passwordEditable = false;
-        m_ui.passwordEditButton->setIcon(KIcon("document-properties"));
+        m_ui.passwordEditButton->setIcon(QIcon::fromTheme("document-properties"));
         m_ui.passwordGridLayout->removeWidget(m_passwordLineEdit);
         InvitationsRfbServer::instance->setDesktopPassword(
                 m_passwordLineEdit->text());
@@ -158,7 +124,7 @@ void MainWindow::editPassword()
         m_passwordLineEdit->setVisible(false);
     } else {
         m_passwordEditable = true;
-        m_ui.passwordEditButton->setIcon(KIcon("document-save"));
+        m_ui.passwordEditButton->setIcon(QIcon::fromTheme("document-save"));
         m_ui.passwordGridLayout->addWidget(m_passwordLineEdit,0,0);
         m_passwordLineEdit->setText(
                 InvitationsRfbServer::instance->desktopPassword());
@@ -190,7 +156,7 @@ void MainWindow::toggleDesktopSharing(bool enable)
         if(m_passwordEditable) {
             m_passwordEditable = false;
             m_passwordLineEdit->setVisible(false);
-            m_ui.passwordEditButton->setIcon(KIcon("document-properties"));
+            m_ui.passwordEditButton->setIcon(QIcon::fromTheme("document-properties"));
         }
     }
 }
@@ -215,25 +181,6 @@ void MainWindow::aboutUnattendedMode()
             i18n("KDE Desktop Sharing"));
 }
 
-#ifdef KRFB_WITH_KDE_TELEPATHY
-
-void MainWindow::onContactDoubleClicked(const Tp::AccountPtr &account, const KTp::ContactPtr &contact)
-{
-    Tp::PendingOperation *op = KTp::Actions::startDesktopSharing(account, contact);
-    connect(op, SIGNAL(finished(Tp::PendingOperation*)),
-            this, SLOT(pendingDesktopShareFinished(Tp::PendingOperation*)));
-}
-
-void MainWindow::pendingDesktopShareFinished(Tp::PendingOperation *operation)
-{
-    if(operation->isError()) {
-        KMessageBox::error(this,
-                operation->errorName() + ": " + operation->errorMessage());
-    }
-}
-
-#endif
-
 void MainWindow::showConfiguration()
 {
     if (KConfigDialog::showDialog("settings")) {
@@ -243,7 +190,6 @@ void MainWindow::showConfiguration()
     KConfigDialog *dialog = new KConfigDialog(this, "settings", KrfbConfig::self());
     dialog->addPage(new TCP, i18n("Network"), "network-workgroup");
     dialog->addPage(new Security, i18n("Security"), "security-high");
-    dialog->setHelp(QString(), "krfb");
     dialog->show();
 }
 
